@@ -15,12 +15,15 @@ def _get_kwargs(
     id: str,
     *,
     no_logs: Union[Unset, None, bool] = UNSET,
+    no_code: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
     params: Dict[str, Any] = {}
     params["no_logs"] = no_logs
 
+    params["no_code"] = no_code
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -79,6 +82,7 @@ def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     no_logs: Union[Unset, None, bool] = UNSET,
+    no_code: Union[Unset, None, bool] = UNSET,
 ) -> Response[Union["GetJobResponse200Type0", "GetJobResponse200Type1"]]:
     """get job
 
@@ -86,6 +90,7 @@ def sync_detailed(
         workspace (str):
         id (str):
         no_logs (Union[Unset, None, bool]):
+        no_code (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -99,6 +104,7 @@ def sync_detailed(
         workspace=workspace,
         id=id,
         no_logs=no_logs,
+        no_code=no_code,
     )
 
     response = client.get_httpx_client().request(
@@ -114,6 +120,7 @@ def sync(
     *,
     client: Union[AuthenticatedClient, Client],
     no_logs: Union[Unset, None, bool] = UNSET,
+    no_code: Union[Unset, None, bool] = UNSET,
 ) -> Optional[Union["GetJobResponse200Type0", "GetJobResponse200Type1"]]:
     """get job
 
@@ -121,6 +128,7 @@ def sync(
         workspace (str):
         id (str):
         no_logs (Union[Unset, None, bool]):
+        no_code (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -135,6 +143,7 @@ def sync(
         id=id,
         client=client,
         no_logs=no_logs,
+        no_code=no_code,
     ).parsed
 
 
@@ -144,6 +153,7 @@ async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
     no_logs: Union[Unset, None, bool] = UNSET,
+    no_code: Union[Unset, None, bool] = UNSET,
 ) -> Response[Union["GetJobResponse200Type0", "GetJobResponse200Type1"]]:
     """get job
 
@@ -151,6 +161,7 @@ async def asyncio_detailed(
         workspace (str):
         id (str):
         no_logs (Union[Unset, None, bool]):
+        no_code (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -164,6 +175,7 @@ async def asyncio_detailed(
         workspace=workspace,
         id=id,
         no_logs=no_logs,
+        no_code=no_code,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -177,6 +189,7 @@ async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
     no_logs: Union[Unset, None, bool] = UNSET,
+    no_code: Union[Unset, None, bool] = UNSET,
 ) -> Optional[Union["GetJobResponse200Type0", "GetJobResponse200Type1"]]:
     """get job
 
@@ -184,6 +197,7 @@ async def asyncio(
         workspace (str):
         id (str):
         no_logs (Union[Unset, None, bool]):
+        no_code (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -199,5 +213,6 @@ async def asyncio(
             id=id,
             client=client,
             no_logs=no_logs,
+            no_code=no_code,
         )
     ).parsed
