@@ -5,15 +5,27 @@ import httpx
 
 from ... import errors
 from ...client import AuthenticatedClient, Client
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
-def _get_kwargs() -> Dict[str, Any]:
+def _get_kwargs(
+    *,
+    workspace: Union[Unset, None, str] = UNSET,
+    show_workspace_restriction: Union[Unset, None, bool] = UNSET,
+) -> Dict[str, Any]:
     pass
 
+    params: Dict[str, Any] = {}
+    params["workspace"] = workspace
+
+    params["show_workspace_restriction"] = show_workspace_restriction
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     return {
         "method": "get",
         "url": "/workers/custom_tags",
+        "params": params,
     }
 
 
@@ -40,9 +52,15 @@ def _build_response(*, client: Union[AuthenticatedClient, Client], response: htt
 def sync_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
+    workspace: Union[Unset, None, str] = UNSET,
+    show_workspace_restriction: Union[Unset, None, bool] = UNSET,
 ) -> Response[List[str]]:
     """get all instance custom tags (tags are used to dispatch jobs to different worker groups)
 
+    Args:
+        workspace (Union[Unset, None, str]):
+        show_workspace_restriction (Union[Unset, None, bool]):
+
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
@@ -51,7 +69,10 @@ def sync_detailed(
         Response[List[str]]
     """
 
-    kwargs = _get_kwargs()
+    kwargs = _get_kwargs(
+        workspace=workspace,
+        show_workspace_restriction=show_workspace_restriction,
+    )
 
     response = client.get_httpx_client().request(
         **kwargs,
@@ -63,9 +84,15 @@ def sync_detailed(
 def sync(
     *,
     client: Union[AuthenticatedClient, Client],
+    workspace: Union[Unset, None, str] = UNSET,
+    show_workspace_restriction: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List[str]]:
     """get all instance custom tags (tags are used to dispatch jobs to different worker groups)
 
+    Args:
+        workspace (Union[Unset, None, str]):
+        show_workspace_restriction (Union[Unset, None, bool]):
+
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
@@ -76,15 +103,23 @@ def sync(
 
     return sync_detailed(
         client=client,
+        workspace=workspace,
+        show_workspace_restriction=show_workspace_restriction,
     ).parsed
 
 
 async def asyncio_detailed(
     *,
     client: Union[AuthenticatedClient, Client],
+    workspace: Union[Unset, None, str] = UNSET,
+    show_workspace_restriction: Union[Unset, None, bool] = UNSET,
 ) -> Response[List[str]]:
     """get all instance custom tags (tags are used to dispatch jobs to different worker groups)
 
+    Args:
+        workspace (Union[Unset, None, str]):
+        show_workspace_restriction (Union[Unset, None, bool]):
+
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
@@ -93,7 +128,10 @@ async def asyncio_detailed(
         Response[List[str]]
     """
 
-    kwargs = _get_kwargs()
+    kwargs = _get_kwargs(
+        workspace=workspace,
+        show_workspace_restriction=show_workspace_restriction,
+    )
 
     response = await client.get_async_httpx_client().request(**kwargs)
 
@@ -103,9 +141,15 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Union[AuthenticatedClient, Client],
+    workspace: Union[Unset, None, str] = UNSET,
+    show_workspace_restriction: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List[str]]:
     """get all instance custom tags (tags are used to dispatch jobs to different worker groups)
 
+    Args:
+        workspace (Union[Unset, None, str]):
+        show_workspace_restriction (Union[Unset, None, bool]):
+
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
@@ -117,5 +161,7 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
+            workspace=workspace,
+            show_workspace_restriction=show_workspace_restriction,
         )
     ).parsed
