@@ -1,11 +1,12 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.app_with_last_version_execution_mode import AppWithLastVersionExecutionMode
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.app_with_last_version_extra_perms import AppWithLastVersionExtraPerms
@@ -31,6 +32,7 @@ class AppWithLastVersion:
         policy (AppWithLastVersionPolicy):
         execution_mode (AppWithLastVersionExecutionMode):
         extra_perms (AppWithLastVersionExtraPerms):
+        custom_path (Union[Unset, str]):
     """
 
     id: int
@@ -44,6 +46,7 @@ class AppWithLastVersion:
     policy: "AppWithLastVersionPolicy"
     execution_mode: AppWithLastVersionExecutionMode
     extra_perms: "AppWithLastVersionExtraPerms"
+    custom_path: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -64,6 +67,8 @@ class AppWithLastVersion:
 
         extra_perms = self.extra_perms.to_dict()
 
+        custom_path = self.custom_path
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -81,6 +86,8 @@ class AppWithLastVersion:
                 "extra_perms": extra_perms,
             }
         )
+        if custom_path is not UNSET:
+            field_dict["custom_path"] = custom_path
 
         return field_dict
 
@@ -113,6 +120,8 @@ class AppWithLastVersion:
 
         extra_perms = AppWithLastVersionExtraPerms.from_dict(d.pop("extra_perms"))
 
+        custom_path = d.pop("custom_path", UNSET)
+
         app_with_last_version = cls(
             id=id,
             workspace_id=workspace_id,
@@ -125,6 +134,7 @@ class AppWithLastVersion:
             policy=policy,
             execution_mode=execution_mode,
             extra_perms=extra_perms,
+            custom_path=custom_path,
         )
 
         app_with_last_version.additional_properties = d
