@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.branch_all_branches_item_modules_item_mock import BranchAllBranchesItemModulesItemMock
     from ..models.branch_all_branches_item_modules_item_retry import BranchAllBranchesItemModulesItemRetry
+    from ..models.branch_all_branches_item_modules_item_skip_if import BranchAllBranchesItemModulesItemSkipIf
     from ..models.branch_all_branches_item_modules_item_sleep_type_0 import BranchAllBranchesItemModulesItemSleepType0
     from ..models.branch_all_branches_item_modules_item_sleep_type_1 import BranchAllBranchesItemModulesItemSleepType1
+    from ..models.branch_all_branches_item_modules_item_stop_after_all_iters_if import (
+        BranchAllBranchesItemModulesItemStopAfterAllItersIf,
+    )
     from ..models.branch_all_branches_item_modules_item_stop_after_if import BranchAllBranchesItemModulesItemStopAfterIf
     from ..models.branch_all_branches_item_modules_item_suspend import BranchAllBranchesItemModulesItemSuspend
 
@@ -24,6 +28,8 @@ class BranchAllBranchesItemModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, BranchAllBranchesItemModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, BranchAllBranchesItemModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, BranchAllBranchesItemModulesItemSkipIf]):
         sleep (Union['BranchAllBranchesItemModulesItemSleepType0', 'BranchAllBranchesItemModulesItemSleepType1',
             Unset]):
         cache_ttl (Union[Unset, float]):
@@ -40,6 +46,8 @@ class BranchAllBranchesItemModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "BranchAllBranchesItemModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "BranchAllBranchesItemModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "BranchAllBranchesItemModulesItemSkipIf"] = UNSET
     sleep: Union[
         "BranchAllBranchesItemModulesItemSleepType0", "BranchAllBranchesItemModulesItemSleepType1", Unset
     ] = UNSET
@@ -65,6 +73,14 @@ class BranchAllBranchesItemModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -107,6 +123,10 @@ class BranchAllBranchesItemModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -134,12 +154,16 @@ class BranchAllBranchesItemModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.branch_all_branches_item_modules_item_mock import BranchAllBranchesItemModulesItemMock
         from ..models.branch_all_branches_item_modules_item_retry import BranchAllBranchesItemModulesItemRetry
+        from ..models.branch_all_branches_item_modules_item_skip_if import BranchAllBranchesItemModulesItemSkipIf
         from ..models.branch_all_branches_item_modules_item_sleep_type_0 import (
             BranchAllBranchesItemModulesItemSleepType0,
         )
         from ..models.branch_all_branches_item_modules_item_sleep_type_1 import (
             BranchAllBranchesItemModulesItemSleepType1,
         )
+        from ..models.branch_all_branches_item_modules_item_stop_after_all_iters_if import (
+            BranchAllBranchesItemModulesItemStopAfterAllItersIf,
+        )
         from ..models.branch_all_branches_item_modules_item_stop_after_if import (
             BranchAllBranchesItemModulesItemStopAfterIf,
         )
@@ -157,6 +181,22 @@ class BranchAllBranchesItemModulesItem:
         else:
             stop_after_if = BranchAllBranchesItemModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, BranchAllBranchesItemModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = BranchAllBranchesItemModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, BranchAllBranchesItemModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = BranchAllBranchesItemModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["BranchAllBranchesItemModulesItemSleepType0", "BranchAllBranchesItemModulesItemSleepType1", Unset]:
@@ -225,6 +265,8 @@ class BranchAllBranchesItemModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
