@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.branch_one_branches_item_modules_item_mock import BranchOneBranchesItemModulesItemMock
     from ..models.branch_one_branches_item_modules_item_retry import BranchOneBranchesItemModulesItemRetry
+    from ..models.branch_one_branches_item_modules_item_skip_if import BranchOneBranchesItemModulesItemSkipIf
     from ..models.branch_one_branches_item_modules_item_sleep_type_0 import BranchOneBranchesItemModulesItemSleepType0
     from ..models.branch_one_branches_item_modules_item_sleep_type_1 import BranchOneBranchesItemModulesItemSleepType1
+    from ..models.branch_one_branches_item_modules_item_stop_after_all_iters_if import (
+        BranchOneBranchesItemModulesItemStopAfterAllItersIf,
+    )
     from ..models.branch_one_branches_item_modules_item_stop_after_if import BranchOneBranchesItemModulesItemStopAfterIf
     from ..models.branch_one_branches_item_modules_item_suspend import BranchOneBranchesItemModulesItemSuspend
 
@@ -24,6 +28,8 @@ class BranchOneBranchesItemModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, BranchOneBranchesItemModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, BranchOneBranchesItemModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, BranchOneBranchesItemModulesItemSkipIf]):
         sleep (Union['BranchOneBranchesItemModulesItemSleepType0', 'BranchOneBranchesItemModulesItemSleepType1',
             Unset]):
         cache_ttl (Union[Unset, float]):
@@ -40,6 +46,8 @@ class BranchOneBranchesItemModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "BranchOneBranchesItemModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "BranchOneBranchesItemModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "BranchOneBranchesItemModulesItemSkipIf"] = UNSET
     sleep: Union[
         "BranchOneBranchesItemModulesItemSleepType0", "BranchOneBranchesItemModulesItemSleepType1", Unset
     ] = UNSET
@@ -65,6 +73,14 @@ class BranchOneBranchesItemModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -107,6 +123,10 @@ class BranchOneBranchesItemModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -134,12 +154,16 @@ class BranchOneBranchesItemModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.branch_one_branches_item_modules_item_mock import BranchOneBranchesItemModulesItemMock
         from ..models.branch_one_branches_item_modules_item_retry import BranchOneBranchesItemModulesItemRetry
+        from ..models.branch_one_branches_item_modules_item_skip_if import BranchOneBranchesItemModulesItemSkipIf
         from ..models.branch_one_branches_item_modules_item_sleep_type_0 import (
             BranchOneBranchesItemModulesItemSleepType0,
         )
         from ..models.branch_one_branches_item_modules_item_sleep_type_1 import (
             BranchOneBranchesItemModulesItemSleepType1,
         )
+        from ..models.branch_one_branches_item_modules_item_stop_after_all_iters_if import (
+            BranchOneBranchesItemModulesItemStopAfterAllItersIf,
+        )
         from ..models.branch_one_branches_item_modules_item_stop_after_if import (
             BranchOneBranchesItemModulesItemStopAfterIf,
         )
@@ -157,6 +181,22 @@ class BranchOneBranchesItemModulesItem:
         else:
             stop_after_if = BranchOneBranchesItemModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, BranchOneBranchesItemModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = BranchOneBranchesItemModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, BranchOneBranchesItemModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = BranchOneBranchesItemModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["BranchOneBranchesItemModulesItemSleepType0", "BranchOneBranchesItemModulesItemSleepType1", Unset]:
@@ -225,6 +265,8 @@ class BranchOneBranchesItemModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
