@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.completed_job_raw_flow_failure_module_mock import CompletedJobRawFlowFailureModuleMock
     from ..models.completed_job_raw_flow_failure_module_retry import CompletedJobRawFlowFailureModuleRetry
+    from ..models.completed_job_raw_flow_failure_module_skip_if import CompletedJobRawFlowFailureModuleSkipIf
     from ..models.completed_job_raw_flow_failure_module_sleep_type_0 import CompletedJobRawFlowFailureModuleSleepType0
     from ..models.completed_job_raw_flow_failure_module_sleep_type_1 import CompletedJobRawFlowFailureModuleSleepType1
+    from ..models.completed_job_raw_flow_failure_module_stop_after_all_iters_if import (
+        CompletedJobRawFlowFailureModuleStopAfterAllItersIf,
+    )
     from ..models.completed_job_raw_flow_failure_module_stop_after_if import CompletedJobRawFlowFailureModuleStopAfterIf
     from ..models.completed_job_raw_flow_failure_module_suspend import CompletedJobRawFlowFailureModuleSuspend
 
@@ -24,6 +28,8 @@ class CompletedJobRawFlowFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, CompletedJobRawFlowFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, CompletedJobRawFlowFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, CompletedJobRawFlowFailureModuleSkipIf]):
         sleep (Union['CompletedJobRawFlowFailureModuleSleepType0', 'CompletedJobRawFlowFailureModuleSleepType1',
             Unset]):
         cache_ttl (Union[Unset, float]):
@@ -40,6 +46,8 @@ class CompletedJobRawFlowFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "CompletedJobRawFlowFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "CompletedJobRawFlowFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "CompletedJobRawFlowFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "CompletedJobRawFlowFailureModuleSleepType0", "CompletedJobRawFlowFailureModuleSleepType1", Unset
     ] = UNSET
@@ -65,6 +73,14 @@ class CompletedJobRawFlowFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -107,6 +123,10 @@ class CompletedJobRawFlowFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -134,12 +154,16 @@ class CompletedJobRawFlowFailureModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.completed_job_raw_flow_failure_module_mock import CompletedJobRawFlowFailureModuleMock
         from ..models.completed_job_raw_flow_failure_module_retry import CompletedJobRawFlowFailureModuleRetry
+        from ..models.completed_job_raw_flow_failure_module_skip_if import CompletedJobRawFlowFailureModuleSkipIf
         from ..models.completed_job_raw_flow_failure_module_sleep_type_0 import (
             CompletedJobRawFlowFailureModuleSleepType0,
         )
         from ..models.completed_job_raw_flow_failure_module_sleep_type_1 import (
             CompletedJobRawFlowFailureModuleSleepType1,
         )
+        from ..models.completed_job_raw_flow_failure_module_stop_after_all_iters_if import (
+            CompletedJobRawFlowFailureModuleStopAfterAllItersIf,
+        )
         from ..models.completed_job_raw_flow_failure_module_stop_after_if import (
             CompletedJobRawFlowFailureModuleStopAfterIf,
         )
@@ -157,6 +181,22 @@ class CompletedJobRawFlowFailureModule:
         else:
             stop_after_if = CompletedJobRawFlowFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, CompletedJobRawFlowFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = CompletedJobRawFlowFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, CompletedJobRawFlowFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = CompletedJobRawFlowFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["CompletedJobRawFlowFailureModuleSleepType0", "CompletedJobRawFlowFailureModuleSleepType1", Unset]:
@@ -225,6 +265,8 @@ class CompletedJobRawFlowFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
