@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.completed_job_raw_flow_modules_item_mock import CompletedJobRawFlowModulesItemMock
     from ..models.completed_job_raw_flow_modules_item_retry import CompletedJobRawFlowModulesItemRetry
+    from ..models.completed_job_raw_flow_modules_item_skip_if import CompletedJobRawFlowModulesItemSkipIf
     from ..models.completed_job_raw_flow_modules_item_sleep_type_0 import CompletedJobRawFlowModulesItemSleepType0
     from ..models.completed_job_raw_flow_modules_item_sleep_type_1 import CompletedJobRawFlowModulesItemSleepType1
+    from ..models.completed_job_raw_flow_modules_item_stop_after_all_iters_if import (
+        CompletedJobRawFlowModulesItemStopAfterAllItersIf,
+    )
     from ..models.completed_job_raw_flow_modules_item_stop_after_if import CompletedJobRawFlowModulesItemStopAfterIf
     from ..models.completed_job_raw_flow_modules_item_suspend import CompletedJobRawFlowModulesItemSuspend
 
@@ -24,6 +28,8 @@ class CompletedJobRawFlowModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, CompletedJobRawFlowModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, CompletedJobRawFlowModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, CompletedJobRawFlowModulesItemSkipIf]):
         sleep (Union['CompletedJobRawFlowModulesItemSleepType0', 'CompletedJobRawFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class CompletedJobRawFlowModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "CompletedJobRawFlowModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "CompletedJobRawFlowModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "CompletedJobRawFlowModulesItemSkipIf"] = UNSET
     sleep: Union["CompletedJobRawFlowModulesItemSleepType0", "CompletedJobRawFlowModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class CompletedJobRawFlowModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class CompletedJobRawFlowModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class CompletedJobRawFlowModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.completed_job_raw_flow_modules_item_mock import CompletedJobRawFlowModulesItemMock
         from ..models.completed_job_raw_flow_modules_item_retry import CompletedJobRawFlowModulesItemRetry
+        from ..models.completed_job_raw_flow_modules_item_skip_if import CompletedJobRawFlowModulesItemSkipIf
         from ..models.completed_job_raw_flow_modules_item_sleep_type_0 import CompletedJobRawFlowModulesItemSleepType0
         from ..models.completed_job_raw_flow_modules_item_sleep_type_1 import CompletedJobRawFlowModulesItemSleepType1
+        from ..models.completed_job_raw_flow_modules_item_stop_after_all_iters_if import (
+            CompletedJobRawFlowModulesItemStopAfterAllItersIf,
+        )
         from ..models.completed_job_raw_flow_modules_item_stop_after_if import CompletedJobRawFlowModulesItemStopAfterIf
         from ..models.completed_job_raw_flow_modules_item_suspend import CompletedJobRawFlowModulesItemSuspend
 
@@ -146,6 +170,22 @@ class CompletedJobRawFlowModulesItem:
         else:
             stop_after_if = CompletedJobRawFlowModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, CompletedJobRawFlowModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = CompletedJobRawFlowModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, CompletedJobRawFlowModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = CompletedJobRawFlowModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["CompletedJobRawFlowModulesItemSleepType0", "CompletedJobRawFlowModulesItemSleepType1", Unset]:
@@ -214,6 +254,8 @@ class CompletedJobRawFlowModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
