@@ -8,7 +8,7 @@ from ..models.create_script_json_body_language import CreateScriptJsonBodyLangua
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.create_script_json_body_fallback_access_types_item import CreateScriptJsonBodyFallbackAccessTypesItem
+    from ..models.create_script_json_body_assets_item import CreateScriptJsonBodyAssetsItem
     from ..models.create_script_json_body_schema import CreateScriptJsonBodySchema
 
 
@@ -48,7 +48,7 @@ class CreateScriptJsonBody:
         codebase (Union[Unset, str]):
         has_preprocessor (Union[Unset, bool]):
         on_behalf_of_email (Union[Unset, str]):
-        fallback_access_types (Union[Unset, List['CreateScriptJsonBodyFallbackAccessTypesItem']]):
+        assets (Union[Unset, List['CreateScriptJsonBodyAssetsItem']]):
     """
 
     path: str
@@ -80,7 +80,7 @@ class CreateScriptJsonBody:
     codebase: Union[Unset, str] = UNSET
     has_preprocessor: Union[Unset, bool] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
-    fallback_access_types: Union[Unset, List["CreateScriptJsonBodyFallbackAccessTypesItem"]] = UNSET
+    assets: Union[Unset, List["CreateScriptJsonBodyAssetsItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -123,13 +123,13 @@ class CreateScriptJsonBody:
         codebase = self.codebase
         has_preprocessor = self.has_preprocessor
         on_behalf_of_email = self.on_behalf_of_email
-        fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
-        if not isinstance(self.fallback_access_types, Unset):
-            fallback_access_types = []
-            for fallback_access_types_item_data in self.fallback_access_types:
-                fallback_access_types_item = fallback_access_types_item_data.to_dict()
+        assets: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.assets, Unset):
+            assets = []
+            for assets_item_data in self.assets:
+                assets_item = assets_item_data.to_dict()
 
-                fallback_access_types.append(fallback_access_types_item)
+                assets.append(assets_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -190,16 +190,14 @@ class CreateScriptJsonBody:
             field_dict["has_preprocessor"] = has_preprocessor
         if on_behalf_of_email is not UNSET:
             field_dict["on_behalf_of_email"] = on_behalf_of_email
-        if fallback_access_types is not UNSET:
-            field_dict["fallback_access_types"] = fallback_access_types
+        if assets is not UNSET:
+            field_dict["assets"] = assets
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.create_script_json_body_fallback_access_types_item import (
-            CreateScriptJsonBodyFallbackAccessTypesItem,
-        )
+        from ..models.create_script_json_body_assets_item import CreateScriptJsonBodyAssetsItem
         from ..models.create_script_json_body_schema import CreateScriptJsonBodySchema
 
         d = src_dict.copy()
@@ -271,14 +269,12 @@ class CreateScriptJsonBody:
 
         on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
 
-        fallback_access_types = []
-        _fallback_access_types = d.pop("fallback_access_types", UNSET)
-        for fallback_access_types_item_data in _fallback_access_types or []:
-            fallback_access_types_item = CreateScriptJsonBodyFallbackAccessTypesItem.from_dict(
-                fallback_access_types_item_data
-            )
+        assets = []
+        _assets = d.pop("assets", UNSET)
+        for assets_item_data in _assets or []:
+            assets_item = CreateScriptJsonBodyAssetsItem.from_dict(assets_item_data)
 
-            fallback_access_types.append(fallback_access_types_item)
+            assets.append(assets_item)
 
         create_script_json_body = cls(
             path=path,
@@ -310,7 +306,7 @@ class CreateScriptJsonBody:
             codebase=codebase,
             has_preprocessor=has_preprocessor,
             on_behalf_of_email=on_behalf_of_email,
-            fallback_access_types=fallback_access_types,
+            assets=assets,
         )
 
         create_script_json_body.additional_properties = d
