@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type7Type(str, Enum):
-    GRAPHQL = "graphql"
+    IDENTITY = "identity"
 
     def __str__(self) -> str:
         return str(self.value)
