@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.flow_preview_value_failure_module_mock import FlowPreviewValueFailureModuleMock
     from ..models.flow_preview_value_failure_module_retry import FlowPreviewValueFailureModuleRetry
+    from ..models.flow_preview_value_failure_module_skip_if import FlowPreviewValueFailureModuleSkipIf
     from ..models.flow_preview_value_failure_module_sleep_type_0 import FlowPreviewValueFailureModuleSleepType0
     from ..models.flow_preview_value_failure_module_sleep_type_1 import FlowPreviewValueFailureModuleSleepType1
+    from ..models.flow_preview_value_failure_module_stop_after_all_iters_if import (
+        FlowPreviewValueFailureModuleStopAfterAllItersIf,
+    )
     from ..models.flow_preview_value_failure_module_stop_after_if import FlowPreviewValueFailureModuleStopAfterIf
     from ..models.flow_preview_value_failure_module_suspend import FlowPreviewValueFailureModuleSuspend
 
@@ -24,6 +28,8 @@ class FlowPreviewValueFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, FlowPreviewValueFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, FlowPreviewValueFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, FlowPreviewValueFailureModuleSkipIf]):
         sleep (Union['FlowPreviewValueFailureModuleSleepType0', 'FlowPreviewValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class FlowPreviewValueFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "FlowPreviewValueFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "FlowPreviewValueFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "FlowPreviewValueFailureModuleSkipIf"] = UNSET
     sleep: Union["FlowPreviewValueFailureModuleSleepType0", "FlowPreviewValueFailureModuleSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class FlowPreviewValueFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class FlowPreviewValueFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class FlowPreviewValueFailureModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.flow_preview_value_failure_module_mock import FlowPreviewValueFailureModuleMock
         from ..models.flow_preview_value_failure_module_retry import FlowPreviewValueFailureModuleRetry
+        from ..models.flow_preview_value_failure_module_skip_if import FlowPreviewValueFailureModuleSkipIf
         from ..models.flow_preview_value_failure_module_sleep_type_0 import FlowPreviewValueFailureModuleSleepType0
         from ..models.flow_preview_value_failure_module_sleep_type_1 import FlowPreviewValueFailureModuleSleepType1
+        from ..models.flow_preview_value_failure_module_stop_after_all_iters_if import (
+            FlowPreviewValueFailureModuleStopAfterAllItersIf,
+        )
         from ..models.flow_preview_value_failure_module_stop_after_if import FlowPreviewValueFailureModuleStopAfterIf
         from ..models.flow_preview_value_failure_module_suspend import FlowPreviewValueFailureModuleSuspend
 
@@ -146,6 +170,22 @@ class FlowPreviewValueFailureModule:
         else:
             stop_after_if = FlowPreviewValueFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, FlowPreviewValueFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = FlowPreviewValueFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, FlowPreviewValueFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = FlowPreviewValueFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["FlowPreviewValueFailureModuleSleepType0", "FlowPreviewValueFailureModuleSleepType1", Unset]:
@@ -214,6 +254,8 @@ class FlowPreviewValueFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
