@@ -24,22 +24,30 @@ class FlowStatusModule:
         id (Union[Unset, str]):
         job (Union[Unset, str]):
         count (Union[Unset, int]):
+        progress (Union[Unset, int]):
         iterator (Union[Unset, FlowStatusModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
+        flow_jobs_success (Union[Unset, List[bool]]):
         branch_chosen (Union[Unset, FlowStatusModuleBranchChosen]):
         branchall (Union[Unset, FlowStatusModuleBranchall]):
         approvers (Union[Unset, List['FlowStatusModuleApproversItem']]):
+        failed_retries (Union[Unset, List[str]]):
+        skipped (Union[Unset, bool]):
     """
 
     type: FlowStatusModuleType
     id: Union[Unset, str] = UNSET
     job: Union[Unset, str] = UNSET
     count: Union[Unset, int] = UNSET
+    progress: Union[Unset, int] = UNSET
     iterator: Union[Unset, "FlowStatusModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
+    flow_jobs_success: Union[Unset, List[bool]] = UNSET
     branch_chosen: Union[Unset, "FlowStatusModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "FlowStatusModuleBranchall"] = UNSET
     approvers: Union[Unset, List["FlowStatusModuleApproversItem"]] = UNSET
+    failed_retries: Union[Unset, List[str]] = UNSET
+    skipped: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -48,6 +56,7 @@ class FlowStatusModule:
         id = self.id
         job = self.job
         count = self.count
+        progress = self.progress
         iterator: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.iterator, Unset):
             iterator = self.iterator.to_dict()
@@ -56,6 +65,10 @@ class FlowStatusModule:
         if not isinstance(self.flow_jobs, Unset):
             flow_jobs = self.flow_jobs
 
+        flow_jobs_success: Union[Unset, List[bool]] = UNSET
+        if not isinstance(self.flow_jobs_success, Unset):
+            flow_jobs_success = self.flow_jobs_success
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -72,6 +85,12 @@ class FlowStatusModule:
 
                 approvers.append(approvers_item)
 
+        failed_retries: Union[Unset, List[str]] = UNSET
+        if not isinstance(self.failed_retries, Unset):
+            failed_retries = self.failed_retries
+
+        skipped = self.skipped
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -85,16 +104,24 @@ class FlowStatusModule:
             field_dict["job"] = job
         if count is not UNSET:
             field_dict["count"] = count
+        if progress is not UNSET:
+            field_dict["progress"] = progress
         if iterator is not UNSET:
             field_dict["iterator"] = iterator
         if flow_jobs is not UNSET:
             field_dict["flow_jobs"] = flow_jobs
+        if flow_jobs_success is not UNSET:
+            field_dict["flow_jobs_success"] = flow_jobs_success
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
             field_dict["branchall"] = branchall
         if approvers is not UNSET:
             field_dict["approvers"] = approvers
+        if failed_retries is not UNSET:
+            field_dict["failed_retries"] = failed_retries
+        if skipped is not UNSET:
+            field_dict["skipped"] = skipped
 
         return field_dict
 
@@ -114,6 +141,8 @@ class FlowStatusModule:
 
         count = d.pop("count", UNSET)
 
+        progress = d.pop("progress", UNSET)
+
         _iterator = d.pop("iterator", UNSET)
         iterator: Union[Unset, FlowStatusModuleIterator]
         if isinstance(_iterator, Unset):
@@ -123,6 +152,8 @@ class FlowStatusModule:
 
         flow_jobs = cast(List[str], d.pop("flow_jobs", UNSET))
 
+        flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, FlowStatusModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -144,16 +175,24 @@ class FlowStatusModule:
 
             approvers.append(approvers_item)
 
+        failed_retries = cast(List[str], d.pop("failed_retries", UNSET))
+
+        skipped = d.pop("skipped", UNSET)
+
         flow_status_module = cls(
             type=type,
             id=id,
             job=job,
             count=count,
+            progress=progress,
             iterator=iterator,
             flow_jobs=flow_jobs,
+            flow_jobs_success=flow_jobs_success,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
+            failed_retries=failed_retries,
+            skipped=skipped,
         )
 
         flow_status_module.additional_properties = d
