@@ -43,7 +43,7 @@ class GcpTrigger:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, GcpTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, GcpTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, GcpTriggerRetry]):
     """
 
