@@ -1,11 +1,12 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.get_app_by_path_response_200_execution_mode import GetAppByPathResponse200ExecutionMode
+from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.get_app_by_path_response_200_extra_perms import GetAppByPathResponse200ExtraPerms
@@ -31,6 +32,7 @@ class GetAppByPathResponse200:
         policy (GetAppByPathResponse200Policy):
         execution_mode (GetAppByPathResponse200ExecutionMode):
         extra_perms (GetAppByPathResponse200ExtraPerms):
+        custom_path (Union[Unset, str]):
     """
 
     id: int
@@ -44,6 +46,7 @@ class GetAppByPathResponse200:
     policy: "GetAppByPathResponse200Policy"
     execution_mode: GetAppByPathResponse200ExecutionMode
     extra_perms: "GetAppByPathResponse200ExtraPerms"
+    custom_path: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -64,6 +67,8 @@ class GetAppByPathResponse200:
 
         extra_perms = self.extra_perms.to_dict()
 
+        custom_path = self.custom_path
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -81,6 +86,8 @@ class GetAppByPathResponse200:
                 "extra_perms": extra_perms,
             }
         )
+        if custom_path is not UNSET:
+            field_dict["custom_path"] = custom_path
 
         return field_dict
 
@@ -113,6 +120,8 @@ class GetAppByPathResponse200:
 
         extra_perms = GetAppByPathResponse200ExtraPerms.from_dict(d.pop("extra_perms"))
 
+        custom_path = d.pop("custom_path", UNSET)
+
         get_app_by_path_response_200 = cls(
             id=id,
             workspace_id=workspace_id,
@@ -125,6 +134,7 @@ class GetAppByPathResponse200:
             policy=policy,
             execution_mode=execution_mode,
             extra_perms=extra_perms,
+            custom_path=custom_path,
         )
 
         get_app_by_path_response_200.additional_properties = d
