@@ -27,6 +27,7 @@ class GetAuditLogResponse200:
         action_kind (GetAuditLogResponse200ActionKind):
         resource (Union[Unset, str]):
         parameters (Union[Unset, GetAuditLogResponse200Parameters]):
+        span (Union[Unset, str]):
     """
 
     id: int
@@ -36,6 +37,7 @@ class GetAuditLogResponse200:
     action_kind: GetAuditLogResponse200ActionKind
     resource: Union[Unset, str] = UNSET
     parameters: Union[Unset, "GetAuditLogResponse200Parameters"] = UNSET
+    span: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -52,6 +54,8 @@ class GetAuditLogResponse200:
         if not isinstance(self.parameters, Unset):
             parameters = self.parameters.to_dict()
 
+        span = self.span
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -67,6 +71,8 @@ class GetAuditLogResponse200:
             field_dict["resource"] = resource
         if parameters is not UNSET:
             field_dict["parameters"] = parameters
+        if span is not UNSET:
+            field_dict["span"] = span
 
         return field_dict
 
@@ -94,6 +100,8 @@ class GetAuditLogResponse200:
         else:
             parameters = GetAuditLogResponse200Parameters.from_dict(_parameters)
 
+        span = d.pop("span", UNSET)
+
         get_audit_log_response_200 = cls(
             id=id,
             timestamp=timestamp,
@@ -102,6 +110,7 @@ class GetAuditLogResponse200:
             action_kind=action_kind,
             resource=resource,
             parameters=parameters,
+            span=span,
         )
 
         get_audit_log_response_200.additional_properties = d
