@@ -44,7 +44,7 @@ class GetCompletedJobResponse200:
         parent_job (Union[Unset, str]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, GetCompletedJobResponse200Args]):
+        args (Union[Unset, GetCompletedJobResponse200Args]): The arguments to pass to the script or flow
         result (Union[Unset, Any]):
         logs (Union[Unset, str]):
         deleted (Union[Unset, bool]):
