@@ -43,7 +43,8 @@ class GetGcpTriggerResponse200:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, GetGcpTriggerResponse200ErrorHandlerArgs]):
+        error_handler_args (Union[Unset, GetGcpTriggerResponse200ErrorHandlerArgs]): The arguments to pass to the script
+            or flow
         retry (Union[Unset, GetGcpTriggerResponse200Retry]):
     """
 
