@@ -8,6 +8,9 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.get_job_response_200_type_1_raw_flow_failure_module import GetJobResponse200Type1RawFlowFailureModule
     from ..models.get_job_response_200_type_1_raw_flow_modules_item import GetJobResponse200Type1RawFlowModulesItem
+    from ..models.get_job_response_200_type_1_raw_flow_preprocessor_module import (
+        GetJobResponse200Type1RawFlowPreprocessorModule,
+    )
 
 
 T = TypeVar("T", bound="GetJobResponse200Type1RawFlow")
@@ -19,6 +22,7 @@ class GetJobResponse200Type1RawFlow:
     Attributes:
         modules (List['GetJobResponse200Type1RawFlowModulesItem']):
         failure_module (Union[Unset, GetJobResponse200Type1RawFlowFailureModule]):
+        preprocessor_module (Union[Unset, GetJobResponse200Type1RawFlowPreprocessorModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
@@ -31,6 +35,7 @@ class GetJobResponse200Type1RawFlow:
 
     modules: List["GetJobResponse200Type1RawFlowModulesItem"]
     failure_module: Union[Unset, "GetJobResponse200Type1RawFlowFailureModule"] = UNSET
+    preprocessor_module: Union[Unset, "GetJobResponse200Type1RawFlowPreprocessorModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
@@ -52,6 +57,10 @@ class GetJobResponse200Type1RawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        preprocessor_module: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.preprocessor_module, Unset):
+            preprocessor_module = self.preprocessor_module.to_dict()
+
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
@@ -70,6 +79,8 @@ class GetJobResponse200Type1RawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if preprocessor_module is not UNSET:
+            field_dict["preprocessor_module"] = preprocessor_module
         if same_worker is not UNSET:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
@@ -95,6 +106,9 @@ class GetJobResponse200Type1RawFlow:
             GetJobResponse200Type1RawFlowFailureModule,
         )
         from ..models.get_job_response_200_type_1_raw_flow_modules_item import GetJobResponse200Type1RawFlowModulesItem
+        from ..models.get_job_response_200_type_1_raw_flow_preprocessor_module import (
+            GetJobResponse200Type1RawFlowPreprocessorModule,
+        )
 
         d = src_dict.copy()
         modules = []
@@ -111,6 +125,13 @@ class GetJobResponse200Type1RawFlow:
         else:
             failure_module = GetJobResponse200Type1RawFlowFailureModule.from_dict(_failure_module)
 
+        _preprocessor_module = d.pop("preprocessor_module", UNSET)
+        preprocessor_module: Union[Unset, GetJobResponse200Type1RawFlowPreprocessorModule]
+        if isinstance(_preprocessor_module, Unset):
+            preprocessor_module = UNSET
+        else:
+            preprocessor_module = GetJobResponse200Type1RawFlowPreprocessorModule.from_dict(_preprocessor_module)
+
         same_worker = d.pop("same_worker", UNSET)
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
@@ -130,6 +151,7 @@ class GetJobResponse200Type1RawFlow:
         get_job_response_200_type_1_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            preprocessor_module=preprocessor_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
