@@ -38,7 +38,8 @@ class GetSqsTriggerResponse200:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, GetSqsTriggerResponse200ErrorHandlerArgs]):
+        error_handler_args (Union[Unset, GetSqsTriggerResponse200ErrorHandlerArgs]): The arguments to pass to the script
+            or flow
         retry (Union[Unset, GetSqsTriggerResponse200Retry]):
     """
 
