@@ -1,11 +1,12 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 if TYPE_CHECKING:
     from ..models.get_suspended_job_flow_response_200_approvers_item import GetSuspendedJobFlowResponse200ApproversItem
-    from ..models.get_suspended_job_flow_response_200_job import GetSuspendedJobFlowResponse200Job
+    from ..models.get_suspended_job_flow_response_200_job_type_0 import GetSuspendedJobFlowResponse200JobType0
+    from ..models.get_suspended_job_flow_response_200_job_type_1 import GetSuspendedJobFlowResponse200JobType1
 
 
 T = TypeVar("T", bound="GetSuspendedJobFlowResponse200")
@@ -15,16 +16,24 @@ T = TypeVar("T", bound="GetSuspendedJobFlowResponse200")
 class GetSuspendedJobFlowResponse200:
     """
     Attributes:
-        job (GetSuspendedJobFlowResponse200Job):
+        job (Union['GetSuspendedJobFlowResponse200JobType0', 'GetSuspendedJobFlowResponse200JobType1']):
         approvers (List['GetSuspendedJobFlowResponse200ApproversItem']):
     """
 
-    job: "GetSuspendedJobFlowResponse200Job"
+    job: Union["GetSuspendedJobFlowResponse200JobType0", "GetSuspendedJobFlowResponse200JobType1"]
     approvers: List["GetSuspendedJobFlowResponse200ApproversItem"]
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        job = self.job.to_dict()
+        from ..models.get_suspended_job_flow_response_200_job_type_0 import GetSuspendedJobFlowResponse200JobType0
+
+        job: Dict[str, Any]
+
+        if isinstance(self.job, GetSuspendedJobFlowResponse200JobType0):
+            job = self.job.to_dict()
+
+        else:
+            job = self.job.to_dict()
 
         approvers = []
         for approvers_item_data in self.approvers:
@@ -48,10 +57,29 @@ class GetSuspendedJobFlowResponse200:
         from ..models.get_suspended_job_flow_response_200_approvers_item import (
             GetSuspendedJobFlowResponse200ApproversItem,
         )
-        from ..models.get_suspended_job_flow_response_200_job import GetSuspendedJobFlowResponse200Job
+        from ..models.get_suspended_job_flow_response_200_job_type_0 import GetSuspendedJobFlowResponse200JobType0
+        from ..models.get_suspended_job_flow_response_200_job_type_1 import GetSuspendedJobFlowResponse200JobType1
 
         d = src_dict.copy()
-        job = GetSuspendedJobFlowResponse200Job.from_dict(d.pop("job"))
+
+        def _parse_job(
+            data: object,
+        ) -> Union["GetSuspendedJobFlowResponse200JobType0", "GetSuspendedJobFlowResponse200JobType1"]:
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                job_type_0 = GetSuspendedJobFlowResponse200JobType0.from_dict(data)
+
+                return job_type_0
+            except:  # noqa: E722
+                pass
+            if not isinstance(data, dict):
+                raise TypeError()
+            job_type_1 = GetSuspendedJobFlowResponse200JobType1.from_dict(data)
+
+            return job_type_1
+
+        job = _parse_job(d.pop("job"))
 
         approvers = []
         _approvers = d.pop("approvers")
