@@ -3,11 +3,14 @@ from enum import Enum
 
 class GetSuspendedJobFlowResponse200JobType1JobKind(str, Enum):
     APPDEPENDENCIES = "appdependencies"
+    APPSCRIPT = "appscript"
     DEPENDENCIES = "dependencies"
     DEPLOYMENTCALLBACK = "deploymentcallback"
     FLOW = "flow"
     FLOWDEPENDENCIES = "flowdependencies"
+    FLOWNODE = "flownode"
     FLOWPREVIEW = "flowpreview"
+    FLOWSCRIPT = "flowscript"
     IDENTITY = "identity"
     PREVIEW = "preview"
     SCRIPT = "script"
