@@ -44,7 +44,7 @@ class HttpTrigger:
         summary (Union[Unset, str]):
         description (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, HttpTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, HttpTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, HttpTriggerRetry]):
     """
 
