@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.list_completed_jobs_response_200_item_raw_flow_modules_item import (
         ListCompletedJobsResponse200ItemRawFlowModulesItem,
     )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_preprocessor_module import (
+        ListCompletedJobsResponse200ItemRawFlowPreprocessorModule,
+    )
 
 
 T = TypeVar("T", bound="ListCompletedJobsResponse200ItemRawFlow")
@@ -23,6 +26,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
     Attributes:
         modules (List['ListCompletedJobsResponse200ItemRawFlowModulesItem']):
         failure_module (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModule]):
+        preprocessor_module (Union[Unset, ListCompletedJobsResponse200ItemRawFlowPreprocessorModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
@@ -35,6 +39,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
 
     modules: List["ListCompletedJobsResponse200ItemRawFlowModulesItem"]
     failure_module: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModule"] = UNSET
+    preprocessor_module: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowPreprocessorModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
@@ -56,6 +61,10 @@ class ListCompletedJobsResponse200ItemRawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        preprocessor_module: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.preprocessor_module, Unset):
+            preprocessor_module = self.preprocessor_module.to_dict()
+
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
@@ -74,6 +83,8 @@ class ListCompletedJobsResponse200ItemRawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if preprocessor_module is not UNSET:
+            field_dict["preprocessor_module"] = preprocessor_module
         if same_worker is not UNSET:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
@@ -101,6 +112,9 @@ class ListCompletedJobsResponse200ItemRawFlow:
         from ..models.list_completed_jobs_response_200_item_raw_flow_modules_item import (
             ListCompletedJobsResponse200ItemRawFlowModulesItem,
         )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_preprocessor_module import (
+            ListCompletedJobsResponse200ItemRawFlowPreprocessorModule,
+        )
 
         d = src_dict.copy()
         modules = []
@@ -117,6 +131,15 @@ class ListCompletedJobsResponse200ItemRawFlow:
         else:
             failure_module = ListCompletedJobsResponse200ItemRawFlowFailureModule.from_dict(_failure_module)
 
+        _preprocessor_module = d.pop("preprocessor_module", UNSET)
+        preprocessor_module: Union[Unset, ListCompletedJobsResponse200ItemRawFlowPreprocessorModule]
+        if isinstance(_preprocessor_module, Unset):
+            preprocessor_module = UNSET
+        else:
+            preprocessor_module = ListCompletedJobsResponse200ItemRawFlowPreprocessorModule.from_dict(
+                _preprocessor_module
+            )
+
         same_worker = d.pop("same_worker", UNSET)
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
@@ -136,6 +159,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
         list_completed_jobs_response_200_item_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            preprocessor_module=preprocessor_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
