@@ -13,17 +13,20 @@ class ListContextualVariablesResponse200Item:
         name (str):
         value (str):
         description (str):
+        is_custom (bool):
     """
 
     name: str
     value: str
     description: str
+    is_custom: bool
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         name = self.name
         value = self.value
         description = self.description
+        is_custom = self.is_custom
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -32,6 +35,7 @@ class ListContextualVariablesResponse200Item:
                 "name": name,
                 "value": value,
                 "description": description,
+                "is_custom": is_custom,
             }
         )
 
@@ -46,10 +50,13 @@ class ListContextualVariablesResponse200Item:
 
         description = d.pop("description")
 
+        is_custom = d.pop("is_custom")
+
         list_contextual_variables_response_200_item = cls(
             name=name,
             value=value,
             description=description,
+            is_custom=is_custom,
         )
 
         list_contextual_variables_response_200_item.additional_properties = d
