@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
         ListQueueResponse200ItemRawFlowModulesItemRetry,
     )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_skip_if import (
+        ListQueueResponse200ItemRawFlowModulesItemSkipIf,
+    )
     from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
         ListQueueResponse200ItemRawFlowModulesItemSleepType0,
     )
     from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_1 import (
         ListQueueResponse200ItemRawFlowModulesItemSleepType1,
     )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_all_iters_if import (
+        ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf,
+    )
     from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_if import (
         ListQueueResponse200ItemRawFlowModulesItemStopAfterIf,
     )
@@ -36,6 +42,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSkipIf]):
         sleep (Union['ListQueueResponse200ItemRawFlowModulesItemSleepType0',
             'ListQueueResponse200ItemRawFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemSkipIf"] = UNSET
     sleep: Union[
         "ListQueueResponse200ItemRawFlowModulesItemSleepType0",
         "ListQueueResponse200ItemRawFlowModulesItemSleepType1",
@@ -79,6 +89,14 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         from ..models.list_queue_response_200_item_raw_flow_modules_item_retry import (
             ListQueueResponse200ItemRawFlowModulesItemRetry,
         )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_skip_if import (
+            ListQueueResponse200ItemRawFlowModulesItemSkipIf,
+        )
         from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_0 import (
             ListQueueResponse200ItemRawFlowModulesItemSleepType0,
         )
         from ..models.list_queue_response_200_item_raw_flow_modules_item_sleep_type_1 import (
             ListQueueResponse200ItemRawFlowModulesItemSleepType1,
         )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_all_iters_if import (
+            ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf,
+        )
         from ..models.list_queue_response_200_item_raw_flow_modules_item_stop_after_if import (
             ListQueueResponse200ItemRawFlowModulesItemStopAfterIf,
         )
@@ -177,6 +205,22 @@ class ListQueueResponse200ItemRawFlowModulesItem:
         else:
             stop_after_if = ListQueueResponse200ItemRawFlowModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = ListQueueResponse200ItemRawFlowModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = ListQueueResponse200ItemRawFlowModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class ListQueueResponse200ItemRawFlowModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
