@@ -1,5 +1,5 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -7,6 +7,10 @@ from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.list_users_response_200_item_added_via import ListUsersResponse200ItemAddedVia
+
+
 T = TypeVar("T", bound="ListUsersResponse200Item")
 
 
@@ -25,6 +29,7 @@ class ListUsersResponse200Item:
         folders_owners (List[str]):
         name (Union[Unset, str]):
         groups (Union[Unset, List[str]]):
+        added_via (Union[Unset, None, ListUsersResponse200ItemAddedVia]):
     """
 
     email: str
@@ -38,6 +43,7 @@ class ListUsersResponse200Item:
     folders_owners: List[str]
     name: Union[Unset, str] = UNSET
     groups: Union[Unset, List[str]] = UNSET
+    added_via: Union[Unset, None, "ListUsersResponse200ItemAddedVia"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -58,6 +64,10 @@ class ListUsersResponse200Item:
         if not isinstance(self.groups, Unset):
             groups = self.groups
 
+        added_via: Union[Unset, None, Dict[str, Any]] = UNSET
+        if not isinstance(self.added_via, Unset):
+            added_via = self.added_via.to_dict() if self.added_via else None
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -77,11 +87,15 @@ class ListUsersResponse200Item:
             field_dict["name"] = name
         if groups is not UNSET:
             field_dict["groups"] = groups
+        if added_via is not UNSET:
+            field_dict["added_via"] = added_via
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.list_users_response_200_item_added_via import ListUsersResponse200ItemAddedVia
+
         d = src_dict.copy()
         email = d.pop("email")
 
@@ -105,6 +119,15 @@ class ListUsersResponse200Item:
 
         groups = cast(List[str], d.pop("groups", UNSET))
 
+        _added_via = d.pop("added_via", UNSET)
+        added_via: Union[Unset, None, ListUsersResponse200ItemAddedVia]
+        if _added_via is None:
+            added_via = None
+        elif isinstance(_added_via, Unset):
+            added_via = UNSET
+        else:
+            added_via = ListUsersResponse200ItemAddedVia.from_dict(_added_via)
+
         list_users_response_200_item = cls(
             email=email,
             username=username,
@@ -117,6 +140,7 @@ class ListUsersResponse200Item:
             folders_owners=folders_owners,
             name=name,
             groups=groups,
+            added_via=added_via,
         )
 
         list_users_response_200_item.additional_properties = d
