@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.open_flow_w_path_value_modules_item_mock import OpenFlowWPathValueModulesItemMock
     from ..models.open_flow_w_path_value_modules_item_retry import OpenFlowWPathValueModulesItemRetry
+    from ..models.open_flow_w_path_value_modules_item_skip_if import OpenFlowWPathValueModulesItemSkipIf
     from ..models.open_flow_w_path_value_modules_item_sleep_type_0 import OpenFlowWPathValueModulesItemSleepType0
     from ..models.open_flow_w_path_value_modules_item_sleep_type_1 import OpenFlowWPathValueModulesItemSleepType1
+    from ..models.open_flow_w_path_value_modules_item_stop_after_all_iters_if import (
+        OpenFlowWPathValueModulesItemStopAfterAllItersIf,
+    )
     from ..models.open_flow_w_path_value_modules_item_stop_after_if import OpenFlowWPathValueModulesItemStopAfterIf
     from ..models.open_flow_w_path_value_modules_item_suspend import OpenFlowWPathValueModulesItemSuspend
 
@@ -24,6 +28,8 @@ class OpenFlowWPathValueModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, OpenFlowWPathValueModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, OpenFlowWPathValueModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, OpenFlowWPathValueModulesItemSkipIf]):
         sleep (Union['OpenFlowWPathValueModulesItemSleepType0', 'OpenFlowWPathValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class OpenFlowWPathValueModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "OpenFlowWPathValueModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "OpenFlowWPathValueModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "OpenFlowWPathValueModulesItemSkipIf"] = UNSET
     sleep: Union["OpenFlowWPathValueModulesItemSleepType0", "OpenFlowWPathValueModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class OpenFlowWPathValueModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class OpenFlowWPathValueModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class OpenFlowWPathValueModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.open_flow_w_path_value_modules_item_mock import OpenFlowWPathValueModulesItemMock
         from ..models.open_flow_w_path_value_modules_item_retry import OpenFlowWPathValueModulesItemRetry
+        from ..models.open_flow_w_path_value_modules_item_skip_if import OpenFlowWPathValueModulesItemSkipIf
         from ..models.open_flow_w_path_value_modules_item_sleep_type_0 import OpenFlowWPathValueModulesItemSleepType0
         from ..models.open_flow_w_path_value_modules_item_sleep_type_1 import OpenFlowWPathValueModulesItemSleepType1
+        from ..models.open_flow_w_path_value_modules_item_stop_after_all_iters_if import (
+            OpenFlowWPathValueModulesItemStopAfterAllItersIf,
+        )
         from ..models.open_flow_w_path_value_modules_item_stop_after_if import OpenFlowWPathValueModulesItemStopAfterIf
         from ..models.open_flow_w_path_value_modules_item_suspend import OpenFlowWPathValueModulesItemSuspend
 
@@ -146,6 +170,22 @@ class OpenFlowWPathValueModulesItem:
         else:
             stop_after_if = OpenFlowWPathValueModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, OpenFlowWPathValueModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = OpenFlowWPathValueModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, OpenFlowWPathValueModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = OpenFlowWPathValueModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["OpenFlowWPathValueModulesItemSleepType0", "OpenFlowWPathValueModulesItemSleepType1", Unset]:
@@ -214,6 +254,8 @@ class OpenFlowWPathValueModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
