@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.queued_job_raw_flow_failure_module_mock import QueuedJobRawFlowFailureModuleMock
     from ..models.queued_job_raw_flow_failure_module_retry import QueuedJobRawFlowFailureModuleRetry
+    from ..models.queued_job_raw_flow_failure_module_skip_if import QueuedJobRawFlowFailureModuleSkipIf
     from ..models.queued_job_raw_flow_failure_module_sleep_type_0 import QueuedJobRawFlowFailureModuleSleepType0
     from ..models.queued_job_raw_flow_failure_module_sleep_type_1 import QueuedJobRawFlowFailureModuleSleepType1
+    from ..models.queued_job_raw_flow_failure_module_stop_after_all_iters_if import (
+        QueuedJobRawFlowFailureModuleStopAfterAllItersIf,
+    )
     from ..models.queued_job_raw_flow_failure_module_stop_after_if import QueuedJobRawFlowFailureModuleStopAfterIf
     from ..models.queued_job_raw_flow_failure_module_suspend import QueuedJobRawFlowFailureModuleSuspend
 
@@ -24,6 +28,8 @@ class QueuedJobRawFlowFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, QueuedJobRawFlowFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, QueuedJobRawFlowFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, QueuedJobRawFlowFailureModuleSkipIf]):
         sleep (Union['QueuedJobRawFlowFailureModuleSleepType0', 'QueuedJobRawFlowFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class QueuedJobRawFlowFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "QueuedJobRawFlowFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "QueuedJobRawFlowFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "QueuedJobRawFlowFailureModuleSkipIf"] = UNSET
     sleep: Union["QueuedJobRawFlowFailureModuleSleepType0", "QueuedJobRawFlowFailureModuleSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +68,14 @@ class QueuedJobRawFlowFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +118,10 @@ class QueuedJobRawFlowFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +149,12 @@ class QueuedJobRawFlowFailureModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.queued_job_raw_flow_failure_module_mock import QueuedJobRawFlowFailureModuleMock
         from ..models.queued_job_raw_flow_failure_module_retry import QueuedJobRawFlowFailureModuleRetry
+        from ..models.queued_job_raw_flow_failure_module_skip_if import QueuedJobRawFlowFailureModuleSkipIf
         from ..models.queued_job_raw_flow_failure_module_sleep_type_0 import QueuedJobRawFlowFailureModuleSleepType0
         from ..models.queued_job_raw_flow_failure_module_sleep_type_1 import QueuedJobRawFlowFailureModuleSleepType1
+        from ..models.queued_job_raw_flow_failure_module_stop_after_all_iters_if import (
+            QueuedJobRawFlowFailureModuleStopAfterAllItersIf,
+        )
         from ..models.queued_job_raw_flow_failure_module_stop_after_if import QueuedJobRawFlowFailureModuleStopAfterIf
         from ..models.queued_job_raw_flow_failure_module_suspend import QueuedJobRawFlowFailureModuleSuspend
 
@@ -146,6 +170,22 @@ class QueuedJobRawFlowFailureModule:
         else:
             stop_after_if = QueuedJobRawFlowFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, QueuedJobRawFlowFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = QueuedJobRawFlowFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, QueuedJobRawFlowFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = QueuedJobRawFlowFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["QueuedJobRawFlowFailureModuleSleepType0", "QueuedJobRawFlowFailureModuleSleepType1", Unset]:
@@ -214,6 +254,8 @@ class QueuedJobRawFlowFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
