@@ -8,7 +8,7 @@ from ..models.raw_script_type import RawScriptType
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.raw_script_asset_fallback_access_types_item import RawScriptAssetFallbackAccessTypesItem
+    from ..models.raw_script_assets_item import RawScriptAssetsItem
     from ..models.raw_script_input_transforms import RawScriptInputTransforms
 
 
@@ -30,7 +30,7 @@ class RawScript:
         concurrency_time_window_s (Union[Unset, float]):
         custom_concurrency_key (Union[Unset, str]):
         is_trigger (Union[Unset, bool]):
-        asset_fallback_access_types (Union[Unset, List['RawScriptAssetFallbackAccessTypesItem']]):
+        assets (Union[Unset, List['RawScriptAssetsItem']]):
     """
 
     input_transforms: "RawScriptInputTransforms"
@@ -44,7 +44,7 @@ class RawScript:
     concurrency_time_window_s: Union[Unset, float] = UNSET
     custom_concurrency_key: Union[Unset, str] = UNSET
     is_trigger: Union[Unset, bool] = UNSET
-    asset_fallback_access_types: Union[Unset, List["RawScriptAssetFallbackAccessTypesItem"]] = UNSET
+    assets: Union[Unset, List["RawScriptAssetsItem"]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -62,13 +62,13 @@ class RawScript:
         concurrency_time_window_s = self.concurrency_time_window_s
         custom_concurrency_key = self.custom_concurrency_key
         is_trigger = self.is_trigger
-        asset_fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
-        if not isinstance(self.asset_fallback_access_types, Unset):
-            asset_fallback_access_types = []
-            for asset_fallback_access_types_item_data in self.asset_fallback_access_types:
-                asset_fallback_access_types_item = asset_fallback_access_types_item_data.to_dict()
+        assets: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.assets, Unset):
+            assets = []
+            for assets_item_data in self.assets:
+                assets_item = assets_item_data.to_dict()
 
-                asset_fallback_access_types.append(asset_fallback_access_types_item)
+                assets.append(assets_item)
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -94,14 +94,14 @@ class RawScript:
             field_dict["custom_concurrency_key"] = custom_concurrency_key
         if is_trigger is not UNSET:
             field_dict["is_trigger"] = is_trigger
-        if asset_fallback_access_types is not UNSET:
-            field_dict["asset_fallback_access_types"] = asset_fallback_access_types
+        if assets is not UNSET:
+            field_dict["assets"] = assets
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.raw_script_asset_fallback_access_types_item import RawScriptAssetFallbackAccessTypesItem
+        from ..models.raw_script_assets_item import RawScriptAssetsItem
         from ..models.raw_script_input_transforms import RawScriptInputTransforms
 
         d = src_dict.copy()
@@ -127,14 +127,12 @@ class RawScript:
 
         is_trigger = d.pop("is_trigger", UNSET)
 
-        asset_fallback_access_types = []
-        _asset_fallback_access_types = d.pop("asset_fallback_access_types", UNSET)
-        for asset_fallback_access_types_item_data in _asset_fallback_access_types or []:
-            asset_fallback_access_types_item = RawScriptAssetFallbackAccessTypesItem.from_dict(
-                asset_fallback_access_types_item_data
-            )
+        assets = []
+        _assets = d.pop("assets", UNSET)
+        for assets_item_data in _assets or []:
+            assets_item = RawScriptAssetsItem.from_dict(assets_item_data)
 
-            asset_fallback_access_types.append(asset_fallback_access_types_item)
+            assets.append(assets_item)
 
         raw_script = cls(
             input_transforms=input_transforms,
@@ -148,7 +146,7 @@ class RawScript:
             concurrency_time_window_s=concurrency_time_window_s,
             custom_concurrency_key=custom_concurrency_key,
             is_trigger=is_trigger,
-            asset_fallback_access_types=asset_fallback_access_types,
+            assets=assets,
         )
 
         raw_script.additional_properties = d
