@@ -12,15 +12,18 @@ T = TypeVar("T", bound="UpdateFolderJsonBody")
 class UpdateFolderJsonBody:
     """
     Attributes:
+        summary (Union[Unset, str]):
         owners (Union[Unset, List[str]]):
         extra_perms (Union[Unset, Any]):
     """
 
+    summary: Union[Unset, str] = UNSET
     owners: Union[Unset, List[str]] = UNSET
     extra_perms: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        summary = self.summary
         owners: Union[Unset, List[str]] = UNSET
         if not isinstance(self.owners, Unset):
             owners = self.owners
@@ -30,6 +33,8 @@ class UpdateFolderJsonBody:
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
+        if summary is not UNSET:
+            field_dict["summary"] = summary
         if owners is not UNSET:
             field_dict["owners"] = owners
         if extra_perms is not UNSET:
@@ -40,11 +45,14 @@ class UpdateFolderJsonBody:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        summary = d.pop("summary", UNSET)
+
         owners = cast(List[str], d.pop("owners", UNSET))
 
         extra_perms = d.pop("extra_perms", UNSET)
 
         update_folder_json_body = cls(
+            summary=summary,
             owners=owners,
             extra_perms=extra_perms,
         )
